@@ -2,6 +2,8 @@ from client import Client
 from script_host import ScriptHost
 from plugin_host import PluginHost
 from uv_stream import UvStream
+from msgpack_stream import MsgpackStream
+from rpc_stream import RPCStream
 from time import sleep
 import logging, os
 
@@ -9,7 +11,8 @@ __all__ = ['connect', 'start_host', 'ScriptHost', 'PluginHost']
 
 
 def connect(address=None, port=None, vim_compatible=False):
-    client = Client(UvStream(address, port), vim_compatible)
+    client = Client(RPCStream(MsgpackStream(UvStream(address, port))),
+                    vim_compatible)
     client.discover_api()
     return client.vim
 
